Nested Containers Example
===============================================================================

:download:`nested.enaml <../../../examples/constrained/nested.enaml>`

.. literalinclude:: ../../../examples/constrained/nested.enaml
    :language: python

::

 $ enaml-run nested.enaml

.. image:: images/nested.png
